Combine All R Files
CombineAllRFiles.RdThis function combines the contents of all R files in a specified directory into one file. Files are combined in alphabetical order and the output file itself is automatically excluded when it is located in the input directory.
Value
A list containing the following elements:
- nQtyCombinedFiles
The number of files combined.
- strCombinedContents
The combined content of all the R files (only if strOutFileName is NA).
- strReturn
A string summarizing the operation, including the names of the combined files.
Examples
if (FALSE) { # \dontrun{
result <- CombineAllRFiles(
strOutFileName = "combined.R",
strDirectory = "/path/to/your/directory"
)
print( result$strReturn )
} # }