Create a CyneRgy Function from a Template
CreateCyneRgyFunction.RdCreates an R script from one of the integration-point templates included with CyneRgy. Call the function without a template name to list the available templates.
Usage
CreateCyneRgyFunction(
strFunctionType = "",
strNewFunctionName = NA,
strDirectory = NA,
bOpen = interactive()
)Arguments
- strFunctionType
Character string naming the template to use.
- strNewFunctionName
Character string used for the function and file name. Defaults to
strFunctionType.- strDirectory
Directory where the file should be created. Defaults to the current working directory.
- bOpen
Logical value indicating whether to open the new file in the active IDE. Defaults to
interactive().